@@ -3,6 +3,14 @@ import strawberry
 from typing import Optional
 
 
+@strawberry.type
+class OAuthPublicConfiguration:
+    clientId: Optional[str] = None
+    authorizationUrl: Optional[str] = None
+    scopes: Optional[str] = None
+    redirectUrl: Optional[str] = None
+
+
 @strawberry.type
 class OAuthProvider:
     name: Optional[str] = None
@@ -20,13 +28,8 @@ class OAuthConfiguration(OAuthProvider):
     clientSecret: Optional[str] = None
 
 
-@strawberry.type
-class SSOConfiguration:
-    oAuthEnabled: Optional[bool] = None
-    oAuth: Optional[OAuthConfiguration] = None
-
-
 __all__ = [
+    "OAuthProvider",
     "OAuthConfiguration",
-    "SSOConfiguration",
+    "OAuthPublicConfiguration",
 ]
