@@ -1,3 +1,3 @@
-from .provider import OAuthProviderConfiguration
+from .provider import OAuthProviderConfiguration, get_provider_configuration
 from .client import OAuthClientConfiguration
 from .handler import OAuthHandler
